FELIX-1988 Ensure the default local file "xyz.properties" is assigned to the DEFAULT_LOCALE to have the default translations

git-svn-id: https://svn.apache.org/repos/asf/felix/trunk@911773 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/webconsole/src/main/java/org/apache/felix/webconsole/internal/i18n/ResourceBundleCache.java b/webconsole/src/main/java/org/apache/felix/webconsole/internal/i18n/ResourceBundleCache.java
index f6721fe..054fb02 100644
--- a/webconsole/src/main/java/org/apache/felix/webconsole/internal/i18n/ResourceBundleCache.java
+++ b/webconsole/src/main/java/org/apache/felix/webconsole/internal/i18n/ResourceBundleCache.java
@@ -141,9 +141,9 @@
                     entryPath = entryPath.substring( start, end );
 
                     // the default language is "name.properties" thus the entry
                     // path is empty and must default to "_"
                     if (entryPath.length() == 0) {
-                        entryPath = "_";
+                        entryPath = "_" + DEFAULT_LOCALE;
                     }
 
                     // only add this entry, if the "language" is not provided
@@ -141,9 +141,9 @@
 
                     // the default language is "name.properties" thus the entry
-                    // path is empty and must default to "_"
+                    // path is empty and must default to "_"+DEFAULT_LOCALE
                     if (entryPath.length() == 0) {